@@ -17,7 +17,7 @@ import os, datetime
 import hashlib
 from collections import deque
 
-VERSION = "1.1.0"
+VERSION = "1.2.0"
 
 ###############################################################
 class idict(object):
@@ -35,11 +35,20 @@ class idict(object):
     self.list.append(item)
     self.ctr += 1
     return self.ctr
-    
+
+  def __contains__(self, v):
+    return v in self.dict
+  
   def index(self, item):
     """Return index for item. None if not in container."""
     return self.dict.get(item, None)
 
+  def __iter__(self):
+    return self.list.__iter__()
+  
+  def __len__(self):
+    return len(self.list)
+  
 ###############################################################  
 class ldict_node(object):
   """Node for ldict that wraps data and holds double-links."""
